# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemFinderOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cron_schedule: Optional[List[str]]
    _cron_schedule_description: Optional[str]
    _description: Optional[str]
    _do_not_use_hierarchy_search_output: Optional[List[HierarchySearchOutputV1]]
    _effective_permissions: Optional[PermissionsV1]
    _enabled: bool
    _executor_id: str
    _id: str
    _include_hierarchy: Optional[bool]
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _last_run_at: Optional[str]
    _last_run_warnings: List[str]
    _name: str
    _scoped_to: Optional[str]
    _searches: List[Any]
    _status_message: Optional[str]
    _timezone: Optional[str]
    _translation_key: Optional[str]
    _type: str


    def __init__(
        self,
        cron_schedule: Optional[List[str]] = None,
        cron_schedule_description: Optional[str] = None,
        description: Optional[str] = None,
        do_not_use_hierarchy_search_output: Optional[List[HierarchySearchOutputV1]] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        enabled: Optional[bool] = None,
        executor_id: Optional[str] = None,
        id: Optional[str] = None,
        include_hierarchy: Optional[bool] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        last_run_at: Optional[str] = None,
        last_run_warnings: Optional[List[str]] = None,
        name: Optional[str] = None,
        scoped_to: Optional[str] = None,
        searches: Optional[List[Any]] = None,
        status_message: Optional[str] = None,
        timezone: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def cron_schedule(self) -> Optional[List[str]]: ...

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule: Optional[List[str]]) -> None: ...

    @property
    def cron_schedule_description(self) -> Optional[str]: ...

    @cron_schedule_description.setter
    def cron_schedule_description(self, cron_schedule_description: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def do_not_use_hierarchy_search_output(self) -> Optional[List[HierarchySearchOutputV1]]: ...

    @do_not_use_hierarchy_search_output.setter
    def do_not_use_hierarchy_search_output(self, do_not_use_hierarchy_search_output: Optional[List[HierarchySearchOutputV1]]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def enabled(self) -> bool: ...

    @enabled.setter
    def enabled(self, enabled: bool) -> None: ...

    @property
    def executor_id(self) -> str: ...

    @executor_id.setter
    def executor_id(self, executor_id: str) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def include_hierarchy(self) -> Optional[bool]: ...

    @include_hierarchy.setter
    def include_hierarchy(self, include_hierarchy: Optional[bool]) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def last_run_at(self) -> Optional[str]: ...

    @last_run_at.setter
    def last_run_at(self, last_run_at: Optional[str]) -> None: ...

    @property
    def last_run_warnings(self) -> List[str]: ...

    @last_run_warnings.setter
    def last_run_warnings(self, last_run_warnings: List[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def searches(self) -> List[Any]: ...

    @searches.setter
    def searches(self, searches: List[Any]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
