# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RunConditionMonitorJobInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'manual_run_data': 'list[ManualRunInputV1]',
        'table_manual_run_data': 'BaseManualRunInputV1'
    }

    attribute_map = {
        'manual_run_data': 'manualRunData',
        'table_manual_run_data': 'tableManualRunData'
    }

    def __init__(self, manual_run_data=None, table_manual_run_data=None):
        """
        RunConditionMonitorJobInputV1 - a model defined in Swagger
        """

        self._manual_run_data = None
        self._table_manual_run_data = None

        if manual_run_data is not None:
          self.manual_run_data = manual_run_data
        if table_manual_run_data is not None:
          self.table_manual_run_data = table_manual_run_data

    @property
    def manual_run_data(self):
        """
        Gets the manual_run_data of this RunConditionMonitorJobInputV1.
        Data for manual run on specific conditions

        :return: The manual_run_data of this RunConditionMonitorJobInputV1.
        :rtype: list[ManualRunInputV1]
        """
        return self._manual_run_data

    @manual_run_data.setter
    def manual_run_data(self, manual_run_data):
        """
        Sets the manual_run_data of this RunConditionMonitorJobInputV1.
        Data for manual run on specific conditions

        :param manual_run_data: The manual_run_data of this RunConditionMonitorJobInputV1.
        :type: list[ManualRunInputV1]
        """

        self._manual_run_data = manual_run_data

    @property
    def table_manual_run_data(self):
        """
        Gets the table_manual_run_data of this RunConditionMonitorJobInputV1.

        :return: The table_manual_run_data of this RunConditionMonitorJobInputV1.
        :rtype: BaseManualRunInputV1
        """
        return self._table_manual_run_data

    @table_manual_run_data.setter
    def table_manual_run_data(self, table_manual_run_data):
        """
        Sets the table_manual_run_data of this RunConditionMonitorJobInputV1.

        :param table_manual_run_data: The table_manual_run_data of this RunConditionMonitorJobInputV1.
        :type: BaseManualRunInputV1
        """

        self._table_manual_run_data = table_manual_run_data

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RunConditionMonitorJobInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
