# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ModelRuleInputV1ListString(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _argument: Optional[List[str]]
    _derived_feature_index: Optional[int]
    _description: Optional[str]
    _id: Optional[str]
    _input_feature_id: Optional[str]
    _input_feature_index: Optional[int]
    _name: str
    _type: str


    def __init__(
        self,
        argument: Optional[List[str]] = None,
        derived_feature_index: Optional[int] = None,
        description: Optional[str] = None,
        id: Optional[str] = None,
        input_feature_id: Optional[str] = None,
        input_feature_index: Optional[int] = None,
        name: Optional[str] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def argument(self) -> Optional[List[str]]: ...

    @argument.setter
    def argument(self, argument: Optional[List[str]]) -> None: ...

    @property
    def derived_feature_index(self) -> Optional[int]: ...

    @derived_feature_index.setter
    def derived_feature_index(self, derived_feature_index: Optional[int]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def input_feature_id(self) -> Optional[str]: ...

    @input_feature_id.setter
    def input_feature_id(self, input_feature_id: Optional[str]) -> None: ...

    @property
    def input_feature_index(self) -> Optional[int]: ...

    @input_feature_index.setter
    def input_feature_index(self, input_feature_index: Optional[int]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
