# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CompositeFilter(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _filter1: Optional[Filter]
    _filter2: Optional[Filter]
    _operation: Optional[str]


    def __init__(
        self,
        filter1: Optional[Filter] = None,
        filter2: Optional[Filter] = None,
        operation: Optional[str] = None,
    ) -> None: ...

    @property
    def filter1(self) -> Optional[Filter]: ...

    @filter1.setter
    def filter1(self, filter1: Optional[Filter]) -> None: ...

    @property
    def filter2(self) -> Optional[Filter]: ...

    @filter2.setter
    def filter2(self, filter2: Optional[Filter]) -> None: ...

    @property
    def operation(self) -> Optional[str]: ...

    @operation.setter
    def operation(self, operation: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
