# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ValueFilter(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_name': 'str',
        'filter_target': 'str',
        'filter_type': 'str',
        'value': 'Value'
    }

    attribute_map = {
        'column_name': 'columnName',
        'filter_target': 'filterTarget',
        'filter_type': 'filterType',
        'value': 'value'
    }

    def __init__(self, column_name=None, filter_target=None, filter_type=None, value=None):
        """
        ValueFilter - a model defined in Swagger
        """

        self._column_name = None
        self._filter_target = None
        self._filter_type = None
        self._value = None

        if column_name is not None:
          self.column_name = column_name
        if filter_target is not None:
          self.filter_target = filter_target
        if filter_type is not None:
          self.filter_type = filter_type
        if value is not None:
          self.value = value

    @property
    def column_name(self):
        """
        Gets the column_name of this ValueFilter.
        The name of the column to filter against. If filtering against context, prepend the name with either 'context_comment.', 'context_label.', or 'context_opaque.'. For example, you can filter for rows with comments updated after a certain date by filtering against 'context_comment.updated_at'

        :return: The column_name of this ValueFilter.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this ValueFilter.
        The name of the column to filter against. If filtering against context, prepend the name with either 'context_comment.', 'context_label.', or 'context_opaque.'. For example, you can filter for rows with comments updated after a certain date by filtering against 'context_comment.updated_at'

        :param column_name: The column_name of this ValueFilter.
        :type: str
        """

        self._column_name = column_name

    @property
    def filter_target(self):
        """
        Gets the filter_target of this ValueFilter.
        Specifies where the filter should be applied: ROW (WHERE clause, filters individual rows before grouping) or AGGREGATED (HAVING clause, filters groups after aggregation). Defaults to ROW for backward compatibility.

        :return: The filter_target of this ValueFilter.
        :rtype: str
        """
        return self._filter_target

    @filter_target.setter
    def filter_target(self, filter_target):
        """
        Sets the filter_target of this ValueFilter.
        Specifies where the filter should be applied: ROW (WHERE clause, filters individual rows before grouping) or AGGREGATED (HAVING clause, filters groups after aggregation). Defaults to ROW for backward compatibility.

        :param filter_target: The filter_target of this ValueFilter.
        :type: str
        """

        self._filter_target = filter_target

    @property
    def filter_type(self):
        """
        Gets the filter_type of this ValueFilter.
        The operation to use in combination with the value

        :return: The filter_type of this ValueFilter.
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """
        Sets the filter_type of this ValueFilter.
        The operation to use in combination with the value

        :param filter_type: The filter_type of this ValueFilter.
        :type: str
        """

        self._filter_type = filter_type

    @property
    def value(self):
        """
        Gets the value of this ValueFilter.

        :return: The value of this ValueFilter.
        :rtype: Value
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ValueFilter.

        :param value: The value of this ValueFilter.
        :type: Value
        """

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ValueFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
