# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableComputeOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'compute_results': 'dict(str, list[RowRulesResultV1])',
        'table_definition': 'TableDefinitionOutputV1'
    }

    attribute_map = {
        'compute_results': 'computeResults',
        'table_definition': 'tableDefinition'
    }

    def __init__(self, compute_results=None, table_definition=None):
        """
        TableComputeOutputV1 - a model defined in Swagger
        """

        self._compute_results = None
        self._table_definition = None

        if compute_results is not None:
          self.compute_results = compute_results
        if table_definition is not None:
          self.table_definition = table_definition

    @property
    def compute_results(self):
        """
        Gets the compute_results of this TableComputeOutputV1.
        The compute results for this table definition

        :return: The compute_results of this TableComputeOutputV1.
        :rtype: dict(str, list[RowRulesResultV1])
        """
        return self._compute_results

    @compute_results.setter
    def compute_results(self, compute_results):
        """
        Sets the compute_results of this TableComputeOutputV1.
        The compute results for this table definition

        :param compute_results: The compute_results of this TableComputeOutputV1.
        :type: dict(str, list[RowRulesResultV1])
        """
        if compute_results is None:
            raise ValueError("Invalid value for `compute_results`, must not be `None`")

        self._compute_results = compute_results

    @property
    def table_definition(self):
        """
        Gets the table_definition of this TableComputeOutputV1.

        :return: The table_definition of this TableComputeOutputV1.
        :rtype: TableDefinitionOutputV1
        """
        return self._table_definition

    @table_definition.setter
    def table_definition(self, table_definition):
        """
        Sets the table_definition of this TableComputeOutputV1.

        :param table_definition: The table_definition of this TableComputeOutputV1.
        :type: TableDefinitionOutputV1
        """
        if table_definition is None:
            raise ValueError("Invalid value for `table_definition`, must not be `None`")

        self._table_definition = table_definition

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableComputeOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
