# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardFilterOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _board_id: str
    _config: Optional[str]
    _display_type: Optional[str]
    _id: str


    def __init__(
        self,
        board_id: Optional[str] = None,
        config: Optional[str] = None,
        display_type: Optional[str] = None,
        id: Optional[str] = None,
    ) -> None: ...

    @property
    def board_id(self) -> str: ...

    @board_id.setter
    def board_id(self, board_id: str) -> None: ...

    @property
    def config(self) -> Optional[str]: ...

    @config.setter
    def config(self, config: Optional[str]) -> None: ...

    @property
    def display_type(self) -> Optional[str]: ...

    @display_type.setter
    def display_type(self, display_type: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
