# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class MaterializedTablesApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def delete_rows(
        self,
        **kwargs: Any,
    ) -> DeleteRowsOutputV1: ...

    def delete_rows_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def publish_events(
        self,
        **kwargs: Any,
    ) -> PublishEventsOutputV1: ...

    def publish_events_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def recompute_table(
        self,
        **kwargs: Any,
    ) -> RecomputeTableOutputV1: ...

    def recompute_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
