# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableSearchInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_ids': 'list[str]',
        'fixed_item_ids': 'list[str]',
        'row_ids': 'list[str]',
        'source_table_id': 'str'
    }

    attribute_map = {
        'column_ids': 'columnIds',
        'fixed_item_ids': 'fixedItemIds',
        'row_ids': 'rowIds',
        'source_table_id': 'sourceTableId'
    }

    def __init__(self, column_ids=None, fixed_item_ids=None, row_ids=None, source_table_id=None):
        """
        TableSearchInputV1 - a model defined in Swagger
        """

        self._column_ids = None
        self._fixed_item_ids = None
        self._row_ids = None
        self._source_table_id = None

        if column_ids is not None:
          self.column_ids = column_ids
        if fixed_item_ids is not None:
          self.fixed_item_ids = fixed_item_ids
        if row_ids is not None:
          self.row_ids = row_ids
        if source_table_id is not None:
          self.source_table_id = source_table_id

    @property
    def column_ids(self):
        """
        Gets the column_ids of this TableSearchInputV1.
        Column IDs to search in the source table. Each column will be searched for items to include as rows in the result.

        :return: The column_ids of this TableSearchInputV1.
        :rtype: list[str]
        """
        return self._column_ids

    @column_ids.setter
    def column_ids(self, column_ids):
        """
        Sets the column_ids of this TableSearchInputV1.
        Column IDs to search in the source table. Each column will be searched for items to include as rows in the result.

        :param column_ids: The column_ids of this TableSearchInputV1.
        :type: list[str]
        """

        self._column_ids = column_ids

    @property
    def fixed_item_ids(self):
        """
        Gets the fixed_item_ids of this TableSearchInputV1.
        Fixed item IDs to include in the backing table. These items will be included regardless of the source table search.

        :return: The fixed_item_ids of this TableSearchInputV1.
        :rtype: list[str]
        """
        return self._fixed_item_ids

    @fixed_item_ids.setter
    def fixed_item_ids(self, fixed_item_ids):
        """
        Sets the fixed_item_ids of this TableSearchInputV1.
        Fixed item IDs to include in the backing table. These items will be included regardless of the source table search.

        :param fixed_item_ids: The fixed_item_ids of this TableSearchInputV1.
        :type: list[str]
        """

        self._fixed_item_ids = fixed_item_ids

    @property
    def row_ids(self):
        """
        Gets the row_ids of this TableSearchInputV1.
        Row IDs to filter results. If provided, only items in these rows will be included from the column results.

        :return: The row_ids of this TableSearchInputV1.
        :rtype: list[str]
        """
        return self._row_ids

    @row_ids.setter
    def row_ids(self, row_ids):
        """
        Sets the row_ids of this TableSearchInputV1.
        Row IDs to filter results. If provided, only items in these rows will be included from the column results.

        :param row_ids: The row_ids of this TableSearchInputV1.
        :type: list[str]
        """

        self._row_ids = row_ids

    @property
    def source_table_id(self):
        """
        Gets the source_table_id of this TableSearchInputV1.
        Source table ID containing the columns to search. Required if columnIds is provided.

        :return: The source_table_id of this TableSearchInputV1.
        :rtype: str
        """
        return self._source_table_id

    @source_table_id.setter
    def source_table_id(self, source_table_id):
        """
        Sets the source_table_id of this TableSearchInputV1.
        Source table ID containing the columns to search. Required if columnIds is provided.

        :param source_table_id: The source_table_id of this TableSearchInputV1.
        :type: str
        """

        self._source_table_id = source_table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableSearchInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
