# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TileLayoutOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _height: int
    _id: str
    _width: int
    _x: int
    _y: int


    def __init__(
        self,
        height: Optional[int] = None,
        id: Optional[str] = None,
        width: Optional[int] = None,
        x: Optional[int] = None,
        y: Optional[int] = None,
    ) -> None: ...

    @property
    def height(self) -> int: ...

    @height.setter
    def height(self, height: int) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def width(self) -> int: ...

    @width.setter
    def width(self, width: int) -> None: ...

    @property
    def x(self) -> int: ...

    @x.setter
    def x(self, x: int) -> None: ...

    @property
    def y(self) -> int: ...

    @y.setter
    def y(self, y: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
